@@ -1,7 +1,8 @@
+#![allow(deprecated)]
 #![allow(clippy::integer_arithmetic)]
 use {
     crate::{
-        declare_sysvar_id,
+        declare_deprecated_sysvar_id,
         fee_calculator::FeeCalculator,
         hash::{hash, Hash},
         sysvar::Sysvar,
@@ -9,31 +10,42 @@ use {
     std::{cmp::Ordering, collections::BinaryHeap, iter::FromIterator, ops::Deref},
 };
 
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
 pub const MAX_ENTRIES: usize = 150;
 
-declare_sysvar_id!(
+declare_deprecated_sysvar_id!(
     "SysvarRecentB1ockHashes11111111111111111111",
     RecentBlockhashes
 );
 
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
 #[repr(C)]
 #[derive(Serialize, Deserialize, Clone, Debug, Default, PartialEq)]
 pub struct Entry {
     pub blockhash: Hash,
     pub fee_calculator: FeeCalculator,
 }
-
 impl Entry {
-    pub fn new(blockhash: &Hash, fee_calculator: &FeeCalculator) -> Self {
+    pub fn new(blockhash: &Hash, lamports_per_signature: u64) -> Self {
         Self {
             blockhash: *blockhash,
-            fee_calculator: fee_calculator.clone(),
+            fee_calculator: FeeCalculator::new(lamports_per_signature),
         }
     }
 }
 
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
 #[derive(Clone, Debug)]
-pub struct IterItem<'a>(pub u64, pub &'a Hash, pub &'a FeeCalculator);
+pub struct IterItem<'a>(pub u64, pub &'a Hash, pub u64);
 
 impl<'a> Eq for IterItem<'a> {}
 
@@ -59,6 +71,10 @@ impl<'a> PartialOrd for IterItem<'a> {
 ///
 /// The entries are ordered by descending block height, so the first entry holds
 /// the most recent block hash, and the last entry holds an old block hash.
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
 #[repr(C)]
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
 pub struct RecentBlockhashes(Vec<Entry>);
@@ -135,13 +151,13 @@ pub fn create_test_recent_blockhashes(start: usize) -> RecentBlockhashes {
             (
                 i as u64,
                 hash(&bincode::serialize(&i).unwrap()),
-                FeeCalculator::new(i as u64 * 100),
+                i as u64 * 100,
             )
         })
         .collect();
     blocks
         .iter()
-        .map(|(i, hash, fee_calc)| IterItem(*i, hash, fee_calc))
+        .map(|(i, hash, lamports_per_signature)| IterItem(*i, hash, *lamports_per_signature))
         .collect()
 }
 
@@ -158,7 +174,7 @@ mod tests {
 
     #[test]
     fn test_size_of() {
-        let entry = Entry::new(&Hash::default(), &FeeCalculator::default());
+        let entry = Entry::new(&Hash::default(), 0);
         assert_eq!(
             bincode::serialized_size(&RecentBlockhashes(vec![entry; MAX_ENTRIES])).unwrap()
                 as usize,
